<?php

use Doctrine\DBAL\Schema\MySqlSchemaManager;
use Doctrine\ORM\Tools\SchemaTool;
use Shopware\CustomModels\TrustedShopsBadge\TrustedShopsBadge;
use Shopware\trus1TrustedShopsBadge\Components\Configuration;
use Shopware\trus1TrustedShopsBadge\Subscriber\Backend;
use Shopware\trus1TrustedShopsBadge\Subscriber\Frontend;

/**
 * Class Shopware_Plugins_Frontend_trus1TrustedShopsBadge_Bootstrap
 *
 * @package Shopware\Plugins\trus1TrustedShopsBadge
 * @author    Trusted Shops GmbH
 * @copyright 2017 Trusted Shops GmbH
 * @license   http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
 * @link      http://www.trustedshops.de/
 */
class Shopware_Plugins_Frontend_trus1TrustedShopsBadge_Bootstrap extends Shopware_Components_Plugin_Bootstrap
{
    /**
     * @return array
     */
    public function getInfo()
    {
        return array(
            'version' => $this->getPluginDescriptionInformation("currentVersion"),
            'copyright' => $this->getPluginDescriptionInformation("copyright"),
            'label' => $this->getPluginDescriptionInformation("label"),
            'description' => file_get_contents($this->Path() . 'info_de.txt') . file_get_contents(
                    $this->Path() . 'info_en.txt'
                ),
            'support' => $this->getPluginDescriptionInformation("support"),
            'link' => $this->getPluginDescriptionInformation("link"),
            'author' => $this->getPluginDescriptionInformation("author")
        );
    }

    /**
     * @return bool
     */
    public function install()
    {
        try {
            $this->subscribeEvent('Enlight_Controller_Front_DispatchLoopStartup', 'onStartDispatch');

            $this->registerController('Backend', 'TrustedShopsBadge');

            $this->createTSMenu();


            $modelManager = Shopware()->Models();
            $schemaTool = new Doctrine\ORM\Tools\SchemaTool($modelManager);
            try {
                $schemaTool->createSchema(
                    array(
                        $modelManager->getClassMetadata('Shopware\CustomModels\TrustedShopsBadge\TrustedShopsBadge')
                    )
                );
            } catch (Exception $e) {
                if ($e) {
                    $schemaTool->dropSchema(array(
                        $modelManager->getClassMetadata('Shopware\CustomModels\TrustedShopsBadge\TrustedShopsBadge')
                    ));
                    $schemaTool->createSchema(
                        array(
                            $modelManager->getClassMetadata('Shopware\CustomModels\TrustedShopsBadge\TrustedShopsBadge')
                        )
                    );
                }
            };
            return true;
        } catch (Exception $e) {
            return array('success' => false, 'message' => $e->getMessage());
        }
    }


    public function update($version)
    {
        //leere den model cache um zu verhindern, dass beim update das gecachete model genutzt wird
        try {
            $cacheManager = Shopware()->Container()->get('shopware.cache_manager');
        } catch (Exception $e) {
        }
        $cacheManager->clearProxyCache();

        $modelManager = Shopware()->Models();
        $tool = new Doctrine\ORM\Tools\SchemaTool($modelManager);
        $schemas = array($modelManager->getClassMetadata('Shopware\CustomModels\TrustedShopsBadge\TrustedShopsBadge'));

        /** @var MySqlSchemaManager $schemaManager */
        $schemaManager = $modelManager->getConnection()->getSchemaManager();
        foreach ($schemas as $class) {
            if (!$schemaManager->tablesExist($class->getTableName())) {
                try {
                    $tool->createSchema(array($class));
                } catch (\Exception $e) {
                    return array('success' => false, 'message' => $e->getMessage());
                }
            } else {
                $modelManager->regenerateProxies();
                $tool->updateSchema(array($class), true); //true - saveMode and not delete other schemas
            }
        }

        //check wether update is successful
        $rowCountAfterUpdate = count(Shopware()->Db()->fetchAll("show columns from s_plugin_trustedshops_badge"));
        //Update was not successfull and the new columns were not created, create them by raw SQL
        if ($rowCountAfterUpdate <= 23) {
            $sql = "ALTER TABLE s_plugin_trustedshops_badge
                            ADD reviewStickerBackgroundColor VARCHAR(255),
                            ADD reviewStickerStarSize INT(11),
                            ADD deliveryTimeOfProduct VARCHAR(255),
                            ADD naDeliveryTimeOfProduct VARCHAR(255),
                            ADD deliveryTimeOfProductExpert VARCHAR(255),
                            ADD naDeliveryTimeOfProductExpert VARCHAR(255),
                            ADD customerRatingsActive TINYINT(1),
                            ADD customerRatingsActiveExpert TINYINT(1),
                            ADD customerRatingsExpertCode LONGTEXT,
                            ADD customerRatingsReviews INT(11),
                            ADD customerRatingsBetterThan VARCHAR(255),
                            ADD customerRatingsBackgroundColor VARCHAR(255),
                            ADD customerRatingsFontFamily VARCHAR(255),
                            ADD richSnippetsActive TINYINT(1),
                            ADD richSnippetsLocations VARCHAR(255),
                            ADD reviewStickerSelector VARCHAR(255),
                            ADD reviewStarsSelector VARCHAR (255),
                            ADD customerReviewsSelector VARCHAR(255),
                            ADD richSnippetsActiveExpert TINYINT(1),
                            ADD richSnippetsLocationsExpert VARCHAR(255),
                            ADD richSnippetsExpertCode LONGTEXT;";

            Shopware()->Db()->executeQuery($sql, array());
        }


        $this->customUpdateSettings();


        return array(
            'success' => true,
            'invalidateCache' => array('config', 'backend', 'proxy', 'frontend', 'template', 'snippets')
        );
    }

    /**
     * @param Enlight_Event_EventArgs $args
     */
    public function onStartDispatch(\Enlight_Event_EventArgs $args)
    {
        /** @var $subject \Enlight_Controller_Action */
        $subject = $args->getSubject();
        $request = $subject->Request();
        if ($request->getModuleName() == 'api') {
            return;
        }
        $modelManager = Shopware()->Models();
        $subscribers = array();
        $tsConfig = null;
        $template = $this->get('template');

        if ($request->getModuleName() == 'backend') {
            $subscribers = array(
                new Backend($this->Path(), $modelManager)
            );
        } else {
            $tsConfig = new Configuration(
                $modelManager,
                $this->get('locale')
            );
            $subscribers = array_merge(
                $subscribers,
                array(new Frontend($tsConfig, $this->Path(), $template, $this->get('shop'))));
        }
        foreach ($subscribers as $subscriber) {
            $this->Application()->Events()->addSubscriber($subscriber);
        }
    }


    /**
     * @param $field
     * @return mixed
     * @throws Exception
     */
    public function getPluginDescriptionInformation($field)
    {
        $info = json_decode(file_get_contents(__DIR__ . DIRECTORY_SEPARATOR . 'plugin.json'), true);
        if (isset($info[$field])) {
            return $info[$field];
        } else {
            throw new Exception('The plugin has an invalid description file. The following field is missing: ' . $field);
        }
    }

    /**
     * @return string
     */
    public function getVersion()
    {
        return $this->getPluginDescriptionInformation("currentVersion");
    }

    /**
     * @return string
     */
    public function getLabel()
    {
        return $this->getPluginDescriptionInformation("label");
    }

    /**
     * @return array
     */
    public function disable()
    {
        return array('success' => true, 'invalidateCache' => array('frontend', 'template', 'config', 'backend'));
    }

    /**
     * @return array|bool
     */
    public function uninstall()
    {
        $this->registerCustomModels();
        $modelManager = Shopware()->Models();
        $schemaTool = new Doctrine\ORM\Tools\SchemaTool($modelManager);
        $classes = array(
            $modelManager->getClassMetadata('Shopware\CustomModels\TrustedShopsBadge\TrustedShopsBadge')
        );
        $schemaTool->dropSchema($classes);
        return parent::uninstall();
    }

    /**
     * @return array
     */
    public function enable()
    {
        return array('success' => true, 'invalidateCache' => array('frontend', 'template', 'config', 'backend'));
    }

    /**
     *
     */
    public function afterInit()
    {
        $this->registerCustomModels();
        $this->Application()->Loader()->registerNamespace('Shopware\trus1TrustedShopsBadge', $this->Path());
    }

    private function createTSMenu()
    {
        $parent = $this->Menu()->findOneBy(array('label' => 'Marketing'));

        $this->createMenuItem(
            array(
                'label' => 'Trusted Shops Trustbadge',
                'controller' => 'TrustedShopsBadge',
                'class' => 'trusted-shops-icon',
                'action' => 'Index',
                'active' => 1,
                'parent' => $parent
            )
        );
    }

    public function customUpdateSettings()
    {
        /* @var TrustedShopsBadge[] $allTrustedShopsConfigurations */
        $allTrustedShopsConfigurations = Shopware()->Models()->getRepository('Shopware\CustomModels\TrustedShopsBadge\TrustedShopsBadge')->findAll();
        $modelManager = Shopware()->Models();
        foreach ($allTrustedShopsConfigurations as $tsConfig) {
            if (!$tsConfig->isExpertMode()) {
                $tsConfig->setTrustedShopsTrustBadgeCode(
                    '<script type="text/javascript">
        (function () {
            var _tsid = \'%tsid%\';
            _tsConfig = {
              \'yOffset\': \'0\', /* offset from page bottom */
              \'variant\': \'reviews\', /* default, reviews, custom, custom_reviews */
              \'customElementId\': \'\', /* required for variants custom and custom_reviews */
              \'trustcardDirection\': \'\', /* for custom variants: topRight, topLeft, bottomRight, bottomLeft */
              \'disableResponsive\': \'false\', /* deactivate responsive behaviour */
              \'disableTrustbadge\': \'false\' /* deactivate trustbadge */

            };
            var _ts = document.createElement(\'script\');
            _ts.type = \'text/javascript\';
            _ts.charset = \'utf-8\';
            _ts.async = true;
            _ts.src = \'//widgets.trustedshops.com/js/\' + _tsid + \'.js\';
            var __ts = document.getElementsByTagName(\'script\')[0];
            __ts.parentNode.insertBefore(_ts, __ts);
          })();
    </script>'
                );
            }

            $tsConfig->setReviewStickerBackgroundColor('#FFFFFF');
            $tsConfig->setReviewStickerStarSize(15);

            if ($tsConfig->getTrustedShopsInStockDeliveryTime() > 0) {
                $tsConfig->setDeliveryTimeOfProduct('custom');
                $tsConfig->setDeliveryTimeOfProductExpert('custom');
            } else {
                $tsConfig->setDeliveryTimeOfProduct('product');
                $tsConfig->setDeliveryTimeOfProductExpert('product');
            }

            if ($tsConfig->getTrustedShopsNotInStockDeliveryTime() > 0) {
                $tsConfig->setNaDeliveryTimeOfProduct('custom');
                $tsConfig->setNaDeliveryTimeOfProductExpert('custom');
            } else {
                $tsConfig->setNaDeliveryTimeOfProduct('product');
                $tsConfig->setNaDeliveryTimeOfProductExpert('product');
            }
            $modelManager->persist($tsConfig);
            try {
                $modelManager->flush($tsConfig);
            } catch (Exception $e) {
                return array('success' => false, 'message' => $e->getMessage());
            }
        }
    }
}
