<?php

namespace Shopware\CustomModels\TrustedShopsBadge;

use Shopware\Components\Model\ModelEntity;
use Doctrine\ORM\Mapping as ORM;

/**
 * @package Shopware\Plugins\trus1TrustedShopsBadge\Models
 * @author    Trusted Shops GmbH
 * @copyright 2017 Trusted Shops GmbH
 * @license   http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
 * @link      http://www.trustedshops.de/
 *
 * @ORM\Entity
 * @ORM\Table(name="s_plugin_trustedshops_badge")
 */
class TrustedShopsBadge extends ModelEntity
{
    /**
     * @var integer $shopId
     *
     * @ORM\Id
     * @ORM\Column(type="integer")
     */
    private $shopId;

    /**
     * @var string $trustedShopId
     *
     * @ORM\Column(type="string", nullable=true)
     */
    private $trustedShopsId;

    /**
     * @var boolean $expertMode
     *
     * @ORM\Column(type="boolean", nullable=true)
     */
    private $expertMode;

    /**
     * @var boolean $trustedShopsShowReviewStickerActive
     *
     * @ORM\Column(type="boolean", nullable=true)
     */
    private $trustedShopsShowReviewStickerActive;

    /**
     * @var string $prodReviewStickerTabName
     *
     * @ORM\Column(type="text", nullable=true)
     */
    private $prodReviewStickerTabName;

    /**
     * @var string $trustedShopsShowReviewStickerCode
     *
     * @ORM\Column(type="text", nullable=true)
     */
    private $trustedShopsShowReviewStickerCode;

    /**
     * @var boolean $trustedShopsShowRatingsStarsActive
     *
     * @ORM\Column(type="boolean", nullable=true)
     */
    private $trustedShopsShowRatingsStarsActive;

    /**
     * @var string $trustedShopsShowRatingsStarsCode
     *
     * @ORM\Column(type="text", nullable=true)
     */
    private $trustedShopsShowRatingsStarsCode;

    /**
     * @var string $trustedShopsTrustBadgeCode
     *
     * @ORM\Column(type="text", nullable=true)
     */
    private $trustedShopsTrustBadgeCode;

    /**
     * @var int $trustedShopsInStockDeliveryTime
     *
     * @ORM\Column(type="integer", nullable=true)
     */
    private $trustedShopsInStockDeliveryTime;

    /**
     * @var int $trustedShopsNotInStockDeliveryTime
     *
     * @ORM\Column(type="integer", nullable=true)
     */
    private $trustedShopsNotInStockDeliveryTime;

    /**
     * @var int $badgeVariant
     *
     * @ORM\Column(type="string", nullable=true)
     */
    private $badgeVariant;

    /**
     * @var int $yOffset
     *
     * @ORM\Column(type="integer", nullable=true)
     */
    private $yOffset;

    /**
     * @var string $prodStickerBorderColor
     *
     * @ORM\Column(type="string", nullable=true)
     */
    private $prodStickerBorderColor;

    /**
     * @var string $prodStickerStarColor
     *
     * @ORM\Column(type="string", nullable=true)
     */
    private $prodStickerStarColor;

    /**
     * @var string $starColor
     *
     * @ORM\Column(type="string", nullable=true)
     */
    private $starColor;

    /**
     * @var int $starSize
     *
     * @ORM\Column(type="integer", nullable=true)
     */
    private $starSize;

    /**
     * @var int $fontSize
     *
     * @ORM\Column(type="integer", nullable=true)
     */
    private $fontSize;

    /**
     * @var boolean $collectRatings
     *
     * @ORM\Column(type="boolean", nullable=true)
     */
    private $collectRatings;

    /**
     * @var boolean $collectRatingsExpert
     *
     * @ORM\Column(type="boolean", nullable=true)
     */
    private $collectRatingsExpert;

    /**
     * @var string $hideEmptyStarRatings
     *
     * @ORM\Column(type="string", nullable=true)
     */
    private $hideEmptyStarRatings;


    /**
     * @var boolean $trustedShopsShowReviewStickerActiveExpert
     *
     * @ORM\Column(type="boolean", nullable=true)
     */
    private $trustedShopsShowReviewStickerActiveExpert;


    /**
     * @var boolean trustedShopsShowRatingsStarsActiveExpert
     *
     * @ORM\Column(type="boolean", nullable=true)
     */
    private $trustedShopsShowRatingsStarsActiveExpert;

    /**
     * @var string $reviewStickerBackgroundColor
     *
     * @ORM\Column(type="string", nullable=true)
     */
    private $reviewStickerBackgroundColor;

    /**
     * @var int $reviewStickerStarSize
     *
     * @ORM\Column(type="integer", nullable=true)
     */
    private $reviewStickerStarSize;

    /**
     * @var string $deliveryTimeOfProduct
     *
     * @ORM\Column(type="string", nullable=true)
     */
    private $deliveryTimeOfProduct;

    /**
     * @var string $naDeliveryTimeOfProduct
     *
     * @ORM\Column(type="string", nullable=true)
     */
    private $naDeliveryTimeOfProduct;

    /**
     * @var string $deliveryTimeOfProductExpert
     *
     * @ORM\Column(type="string", nullable=true)
     */
    private $deliveryTimeOfProductExpert;

    /**
     * @var string $naDeliveryTimeOfProductExpert
     *
     * @ORM\Column(type="string", nullable=true)
     */
    private $naDeliveryTimeOfProductExpert;

    /**
     * @var boolean $customerRatingsActive
     *
     * @ORM\Column(type="boolean", nullable=true)
     */
    private $customerRatingsActive;

    /**
     * @var boolean $customerRatingsActiveExpert
     *
     * @ORM\Column(type="boolean", nullable=true)
     */
    private $customerRatingsActiveExpert;

    /**
     * @var string $customerRatingsExpertCode
     *
     * @ORM\Column(type="text", nullable=true)
     */
    private $customerRatingsExpertCode;

    /**
     * @var integer $customerRatingsReviews
     *
     * @ORM\Column(type="integer", nullable=true)
     */
    private $customerRatingsReviews;

    /**
     * @var string $customerRatingsBetterThan
     *
     * @ORM\Column(type="string", nullable=true)
     */
    private $customerRatingsBetterThan;

    /**
     * @var string $customerRatingsBackgroundColor
     *
     * @ORM\Column(type="string", nullable=true)
     */
    private $customerRatingsBackgroundColor;


    /**
     * @var string $customerRatingsFontFamily
     *
     * @ORM\Column(type="string", nullable=true)
     */
    private $customerRatingsFontFamily;

    /**
     * @var boolean $richSnippetsActive
     *
     * @ORM\Column(type="boolean", nullable=true)
     */
    private $richSnippetsActive;

    /**
     * @var string $richSnippetsLocations
     *
     * @ORM\Column(type="string", nullable=true)
     */
    private $richSnippetsLocations;

    /**
     * @var string $reviewStickerSelector
     *
     * @ORM\Column(type="string", nullable=true)
     */
    private $reviewStickerSelector;

    /**
     * @var string $reviewStarsSelector
     *
     * @ORM\Column(type="string", nullable=true)
     */
    private $reviewStarsSelector;

    /**
     * @var string $customerReviewsSelector
     *
     * @ORM\Column(type="string", nullable=true)
     */
    private $customerReviewsSelector;

    /**
     * @var boolean $richSnippetsActive
     *
     * @ORM\Column(type="boolean", nullable=true)
     */
    private $richSnippetsActiveExpert;

    /**
     * @var string $richSnippetsLocations
     *
     * @ORM\Column(type="string", nullable=true)
     */
    private $richSnippetsLocationsExpert;

    /**
     * @var text $richSnippetsExpertCode
     *
     * @ORM\Column(type="text", nullable=true)
     */
    private $richSnippetsExpertCode;

    /**
     * @return bool
     */
    public function isRichSnippetsActiveExpert()
    {
        return $this->richSnippetsActiveExpert;
    }

    /**
     * @param bool $richSnippetsActiveExpert
     */
    public function setRichSnippetsActiveExpert($richSnippetsActiveExpert)
    {
        $this->richSnippetsActiveExpert = $richSnippetsActiveExpert;
    }

    /**
     * @return string
     */
    public function getRichSnippetsLocationsExpert()
    {
        return $this->richSnippetsLocationsExpert;
    }

    /**
     * @param string $richSnippetsLocationsExpert
     */
    public function setRichSnippetsLocationsExpert($richSnippetsLocationsExpert)
    {
        $this->richSnippetsLocationsExpert = $richSnippetsLocationsExpert;
    }

    /**
     * @return text
     */
    public function getRichSnippetsExpertCode()
    {
        return $this->richSnippetsExpertCode;
    }

    /**
     * @param text $richSnippetsExpertCode
     */
    public function setRichSnippetsExpertCode($richSnippetsExpertCode)
    {
        $this->richSnippetsExpertCode = $richSnippetsExpertCode;
    }

    /**
     * @return string
     */
    public function getReviewStickerSelector()
    {
        return $this->reviewStickerSelector;
    }

    /**
     * @param string $reviewStickerSelector
     */
    public function setReviewStickerSelector($reviewStickerSelector)
    {
        $this->reviewStickerSelector = $reviewStickerSelector;
    }

    /**
     * @return string
     */
    public function getReviewStarsSelector()
    {
        return $this->reviewStarsSelector;
    }

    /**
     * @param string $reviewStarsSelector
     */
    public function setReviewStarsSelector($reviewStarsSelector)
    {
        $this->reviewStarsSelector = $reviewStarsSelector;
    }

    /**
     * @return string
     */
    public function getCustomerReviewsSelector()
    {
        return $this->customerReviewsSelector;
    }

    /**
     * @param string $customerReviewsSelector
     */
    public function setCustomerReviewsSelector($customerReviewsSelector)
    {
        $this->customerReviewsSelector = $customerReviewsSelector;
    }


    /**
     * @return bool
     */
    public function isRichSnippetsActive()
    {
        return $this->richSnippetsActive;
    }

    /**
     * @param bool $richSnippetsActive
     */
    public function setRichSnippetsActive($richSnippetsActive)
    {
        $this->richSnippetsActive = $richSnippetsActive;
    }

    /**
     * @return string
     */
    public function getRichSnippetsLocations()
    {
        return $this->richSnippetsLocations;
    }

    /**
     * @param string $richSnippetsLocations
     */
    public function setRichSnippetsLocations($richSnippetsLocations)
    {
        $this->richSnippetsLocations = $richSnippetsLocations;
    }

    /**
     * @return bool
     */
    public function isCustomerRatingsActive()
    {
        return $this->customerRatingsActive;
    }

    /**
     * @param bool $customerRatingsActive
     */
    public function setCustomerRatingsActive($customerRatingsActive)
    {
        $this->customerRatingsActive = $customerRatingsActive;
    }

    /**
     * @return bool
     */
    public function isCustomerRatingsActiveExpert()
    {
        return $this->customerRatingsActiveExpert;
    }

    /**
     * @param bool $customerRatingsActiveExpert
     */
    public function setCustomerRatingsActiveExpert($customerRatingsActiveExpert)
    {
        $this->customerRatingsActiveExpert = $customerRatingsActiveExpert;
    }

    /**
     * @return bool
     */
    public function isCustomerRatingsExpertCode()
    {
        return $this->customerRatingsExpertCode;
    }

    /**
     * @param bool $customerRatingsExpertCode
     */
    public function setCustomerRatingsExpertCode($customerRatingsExpertCode)
    {
        $this->customerRatingsExpertCode = $customerRatingsExpertCode;
    }

    /**
     * @return int
     */
    public function getCustomerRatingsReviews()
    {
        return $this->customerRatingsReviews;
    }

    /**
     * @param int $customerRatingsReviews
     */
    public function setCustomerRatingsReviews($customerRatingsReviews)
    {
        $this->customerRatingsReviews = $customerRatingsReviews;
    }

    /**
     * @return string
     */
    public function getCustomerRatingsBetterThan()
    {
        return $this->customerRatingsBetterThan;
    }

    /**
     * @param string $customerRatingsBetterThan
     */
    public function setCustomerRatingsBetterThan($customerRatingsBetterThan)
    {
        $this->customerRatingsBetterThan = $customerRatingsBetterThan;
    }

    /**
     * @return string
     */
    public function getCustomerRatingsBackgroundColor()
    {
        return $this->customerRatingsBackgroundColor;
    }

    /**
     * @param string $customerRatingsBackgroundColor
     */
    public function setCustomerRatingsBackgroundColor($customerRatingsBackgroundColor)
    {
        $this->customerRatingsBackgroundColor = $customerRatingsBackgroundColor;
    }

    /**
     * @return string
     */
    public function getCustomerRatingsFontFamily()
    {
        return $this->customerRatingsFontFamily;
    }

    /**
     * @param string $customerRatingsFontFamily
     */
    public function setCustomerRatingsFontFamily($customerRatingsFontFamily)
    {
        $this->customerRatingsFontFamily = $customerRatingsFontFamily;
    }

    /**
     * @return string
     */
    public function getDeliveryTimeOfProductExpert()
    {
        return $this->deliveryTimeOfProductExpert;
    }

    /**
     * @param string $deliveryTimeOfProductExpert
     */
    public function setDeliveryTimeOfProductExpert($deliveryTimeOfProductExpert)
    {
        $this->deliveryTimeOfProductExpert = $deliveryTimeOfProductExpert;
    }

    /**
     * @return string
     */
    public function getNaDeliveryTimeOfProductExpert()
    {
        return $this->naDeliveryTimeOfProductExpert;
    }

    /**
     * @param string $naDeliveryTimeOfProductExpert
     */
    public function setNaDeliveryTimeOfProductExpert($naDeliveryTimeOfProductExpert)
    {
        $this->naDeliveryTimeOfProductExpert = $naDeliveryTimeOfProductExpert;
    }

    /**
     * @return string
     */
    public function getDeliveryTimeOfProduct()
    {
        return $this->deliveryTimeOfProduct;
    }

    /**
     * @param string $deliveryTimeOfProduct
     */
    public function setDeliveryTimeOfProduct($deliveryTimeOfProduct)
    {
        $this->deliveryTimeOfProduct = $deliveryTimeOfProduct;
    }

    /**
     * @return string
     */
    public function getNaDeliveryTimeOfProduct()
    {
        return $this->naDeliveryTimeOfProduct;
    }

    /**
     * @param string $naDeliveryTimeOfProduct
     */
    public function setNaDeliveryTimeOfProduct($naDeliveryTimeOfProduct)
    {
        $this->naDeliveryTimeOfProduct = $naDeliveryTimeOfProduct;
    }

    /**
     * @return string
     */
    public function getReviewStickerBackgroundColor()
    {
        return $this->reviewStickerBackgroundColor;
    }

    /**
     * @param string $reviewStickerBackgroundColor
     */
    public function setReviewStickerBackgroundColor($reviewStickerBackgroundColor)
    {
        $this->reviewStickerBackgroundColor = $reviewStickerBackgroundColor;
    }

    /**
     * @return int
     */
    public function getReviewStickerStarSize()
    {
        return $this->reviewStickerStarSize;
    }

    /**
     * @param int $reviewStickerStarSize
     */
    public function setReviewStickerStarSize($reviewStickerStarSize)
    {
        $this->reviewStickerStarSize = $reviewStickerStarSize;
    }

    /**
     * @return mixed
     */
    public function getTrustedShopsShowRatingsStarsActiveExpert()
    {
        return $this->trustedShopsShowRatingsStarsActiveExpert;
    }

    /**
     * @param mixed $trustedShopsShowRatingsStarsActiveExpert
     */
    public function setTrustedShopsShowRatingsStarsActiveExpert($trustedShopsShowRatingsStarsActiveExpert)
    {
        $this->trustedShopsShowRatingsStarsActiveExpert = $trustedShopsShowRatingsStarsActiveExpert;
    }

    /**
     * @return mixed
     */
    public function getTrustedShopsShowReviewStickerActiveExpert()
    {
        return $this->trustedShopsShowReviewStickerActiveExpert;
    }

    /**
     * @param mixed $trustedShopsShowReviewStickerActiveExpert
     */
    public function setTrustedShopsShowReviewStickerActiveExpert($trustedShopsShowReviewStickerActiveExpert)
    {
        $this->trustedShopsShowReviewStickerActiveExpert = $trustedShopsShowReviewStickerActiveExpert;
    }


    /**
     * @return string
     */
    public function getHideEmptyStarRatings()
    {
        return $this->hideEmptyStarRatings;
    }

    /**
     * @param string $hideEmptyStarRatings
     */
    public function setHideEmptyStarRatings($hideEmptyStarRatings)
    {
        $this->hideEmptyStarRatings = $hideEmptyStarRatings;
    }

    /**
     * @return string
     */
    public function getBadgeVariant()
    {
        return $this->badgeVariant;
    }

    /**
     * @param string $badgeVariant
     */
    public function setBadgeVariant($badgeVariant)
    {
        $this->badgeVariant = $badgeVariant;
    }

    /**
     * @return int
     */
    public function getYOffset()
    {
        return $this->yOffset;
    }

    /**
     * @param int $yOffset
     */
    public function setYOffset($yOffset)
    {
        $this->yOffset = $yOffset;
    }

    /**
     * @return string
     */
    public function getProdStickerBorderColor()
    {
        return $this->prodStickerBorderColor;
    }

    /**
     * @param string $prodStickerBorderColor
     */
    public function setProdStickerBorderColor($prodStickerBorderColor)
    {
        $this->prodStickerBorderColor = $prodStickerBorderColor;
    }

    /**
     * @return string
     */
    public function getProdStickerStarColor()
    {
        return $this->prodStickerStarColor;
    }

    /**
     * @param string $prodStickerStarColor
     */
    public function setProdStickerStarColor($prodStickerStarColor)
    {
        $this->prodStickerStarColor = $prodStickerStarColor;
    }

    /**
     * @return string
     */
    public function getStarColor()
    {
        return $this->starColor;
    }

    /**
     * @param string $starColor
     */
    public function setStarColor($starColor)
    {
        $this->starColor = $starColor;
    }

    /**
     * @return int
     */
    public function getStarSize()
    {
        return $this->starSize;
    }

    /**
     * @param int $starSize
     */
    public function setStarSize($starSize)
    {
        $this->starSize = $starSize;
    }

    /**
     * @return int
     */
    public function getFontSize()
    {
        return $this->fontSize;
    }

    /**
     * @param int $fontSize
     */
    public function setFontSize($fontSize)
    {
        $this->fontSize = $fontSize;
    }

    /**
     * @return boolean
     */
    public function isCollectRatings()
    {
        return $this->collectRatings;
    }

    /**
     * @param boolean $collectRatings
     */
    public function setCollectRatings($collectRatings)
    {
        $this->collectRatings = $collectRatings;
    }

    /**
     * @return boolean
     */
    public function isCollectRatingsExpert()
    {
        return $this->collectRatingsExpert;
    }

    /**
     * @param boolean $collectRatingsExpert
     */
    public function setCollectRatingsExpert($collectRatingsExpert)
    {
        $this->collectRatingsExpert = $collectRatingsExpert;
    }

    /**
     * @param boolean $expertMode
     */
    public function setExpertMode($expertMode)
    {
        $this->expertMode = $expertMode;
    }

    /**
     * @return boolean
     */
    public function isExpertMode()
    {
        return $this->expertMode;
    }

    /**
     * @param string $trustedShopsShowRatingsStarsCode
     */
    public function setTrustedShopsShowRatingsStarsCode($trustedShopsShowRatingsStarsCode)
    {
        $this->trustedShopsShowRatingsStarsCode = $trustedShopsShowRatingsStarsCode;
    }

    /**
     * @return string
     */
    public function getTrustedShopsShowRatingsStarsCode()
    {
        return $this->trustedShopsShowRatingsStarsCode;
    }

    /**
     * @param int $shopId
     */
    public function setShopId($shopId)
    {
        $this->shopId = $shopId;
    }

    /**
     * @return int
     */
    public function getShopId()
    {
        return $this->shopId;
    }

    /**
     * @param string $trustedShopId
     */
    public function setTrustedShopsId($trustedShopId)
    {
        $this->trustedShopsId = $trustedShopId;
    }

    /**
     * @return string
     */
    public function getTrustedShopsId()
    {
        return $this->trustedShopsId;
    }


    /**
     * @param $trustedShopsShowReviewStickerActive
     */
    public function setTrustedShopsShowReviewStickerActive($trustedShopsShowReviewStickerActive)
    {
        $this->trustedShopsShowReviewStickerActive = $trustedShopsShowReviewStickerActive;
    }

    /**
     * @param $trustedShopsShowReviewStickerCode
     */
    public function setTrustedShopsShowReviewStickerCode($trustedShopsShowReviewStickerCode)
    {
        $this->trustedShopsShowReviewStickerCode = $trustedShopsShowReviewStickerCode;
    }

    /**
     * @return boolean
     */
    public function getTrustedShopsShowReviewStickerActive()
    {
        return $this->trustedShopsShowReviewStickerActive;
    }

    /**
     * @return string
     */
    public function getTrustedShopsShowReviewStickerCode()
    {
        return $this->trustedShopsShowReviewStickerCode;
    }

    /**
     * @param $trustedShopsShowRatingsStarsActive
     */
    public function setTrustedShopsShowRatingsStarsActive($trustedShopsShowRatingsStarsActive)
    {
        $this->trustedShopsShowRatingsStarsActive = $trustedShopsShowRatingsStarsActive;
    }

    /**
     * @return boolean
     */
    public function getTrustedShopsShowRatingsStarsActive()
    {
        return $this->trustedShopsShowRatingsStarsActive;
    }


    /**
     * @return string
     */
    public function getTrustedShopsTrustBadgeCode()
    {
        return $this->trustedShopsTrustBadgeCode;
    }

    /**
     * @param string $trustedShopsTrustBadgeCode
     */
    public function setTrustedShopsTrustBadgeCode($trustedShopsTrustBadgeCode)
    {
        $this->trustedShopsTrustBadgeCode = $trustedShopsTrustBadgeCode;
    }

    /**
     * @return int
     */
    public function getTrustedShopsInStockDeliveryTime()
    {
        return $this->trustedShopsInStockDeliveryTime;
    }

    /**
     * @param int $trustedShopsInStockDeliveryTime
     * @return $this
     */
    public function setTrustedShopsInStockDeliveryTime($trustedShopsInStockDeliveryTime)
    {
        $this->trustedShopsInStockDeliveryTime = $trustedShopsInStockDeliveryTime;

        return $this;
    }

    /**
     * @return int
     */
    public function getTrustedShopsNotInStockDeliveryTime()
    {
        return $this->trustedShopsNotInStockDeliveryTime;
    }

    /**
     * @param int $trustedShopsNotInStockDeliveryTime
     * @return $this
     */
    public function setTrustedShopsNotInStockDeliveryTime($trustedShopsNotInStockDeliveryTime)
    {
        $this->trustedShopsNotInStockDeliveryTime = $trustedShopsNotInStockDeliveryTime;

        return $this;
    }

    /**
     * @return mixed
     */
    public function getProdReviewStickerTabName()
    {
        return $this->prodReviewStickerTabName;
    }

    /**
     * @param mixed $prodReviewStickerTabName
     */
    public function setProdReviewStickerTabName($prodReviewStickerTabName)
    {
        $this->prodReviewStickerTabName = $prodReviewStickerTabName;
    }
}
