//{namespace name="trusted_shops_badge"}
//{block name="backend/trusted_shops_badge/controller/main"}
Ext.define('Shopware.apps.TrustedShopsBadge.controller.Main', {
    extend: 'Enlight.app.Controller',

    /**
     * Setting component references for easy access
     * @array
     */
    refs: [
        { ref: 'tsMainForm', selector: 'trustedShops-main-window form[name=trusted-shops-form-panel]' },
        { ref: 'shopCombo', selector: 'trustedShops-main-window field[name=shop-combo]' },
        { ref: 'tsBadgeTabTSID', selector: 'trustedShops-main-badge field[name=trustedShopsId]' },
        { ref: 'tsBadgeTabCode', selector: 'trustedShops-main-badge field[name=trustedShopsTrustBadgeCode]' }
    ],

    snippets: {
        onSaveTitle: '{s name=controller/onSaveTitle}Saved{/s}',
        onSaveText: '{s name=controller/onSaveText}Configuration was saved.{/s}',
        tsRegisterLink: '{s name=controller/tsRegisterLink}{/s}'
    },
    /**
     * Initializes the trustedshops plugin view
     */
    init: function() {
        var me = this;
        if (Ext.getBody().getViewSize().height - 100 > 900) {
            windowOptimizedHeight = 900
        } else {
            windowOptimizedHeight = Ext.getBody().getViewSize().height - 100;
        }

        me.mainWindow = me.getView('main.Window').create({
            height: windowOptimizedHeight,
            width: 700
        }).show();
        me.loadRecord();
        me.control({
            'trustedShops-main-window': {
                changeShop: me.onChangeShop,
                saveTrustedShops: me.onSaveTrustedShops,
                onChangeExpertModeSetting: me.onChangeExpertModeSetting,
                openRegisterUrl: me.onOpenRegisterUrl,
                resetTsSettings: me.onResetTsSettings
            },
            'trustedShops-main-badge': {
                onChangeStarsSwitch: me.onChangeStarsSwitch,
                onChangeStickerSwitch: me.onChangeStickerSwitch,
                onEnableRatingsCollection: me.onEnableRatingsCollection,
                onChangeDeliveryTimeOfProduct: me.onChangeDeliveryTimeOfProduct,
                onChangeNaDeliveryTimeOfProduct: me.onChangeNaDeliveryTimeOfProduct,
                onEnableCustomerRatings: me.onEnableCustomerRatings,
                onEnableRichSnippets: me.onEnableRichSnippets
            },
            'trustedShops-main-expert': {
                onEnableRatingsCollectionExpert: me.onEnableRatingsCollectionExpert,
                onChangeStarsSwitchExpert: me.onChangeStarsSwitchExpert,
                onChangeStickerSwitchExpert: me.onChangeStickerSwitchExpert,
                onChangeNaDeliveryTimeOfProductExpert: me.onChangeNaDeliveryTimeOfProductExpert,
                onChangeDeliveryTimeOfProductExpert: me.onChangeDeliveryTimeOfProductExpert,
                onChangeCustomerRatingsActiveExpert: me.onChangeCustomerRatingsActiveExpert,
                onEnableRichSnippetsExpert: me.onEnableRichSnippetsExpert

            }
        })
    },

    /**
     * gets the trustedshops data
     */
    loadRecord: function() {
        var me = this,
            shopId = me.getShopCombo().getValue(),
            store = Ext.create('Shopware.apps.TrustedShopsBadge.store.TrustedShopsBadge'),
            formPanel = me.mainWindow.formPanel,
            record;

        if (!shopId) {
            shopId = 1;
        }

        store.getProxy().extraParams.shopId = shopId;

        store.load({
            callback: function() {
                record = store.getById(shopId);
                formPanel.setLoading(true);
                setTimeout(function() {
                    formPanel.setLoading(false);
                }, 250);

                me.loadRecordIntoView(record);

                // function compareArrays(haystack, arr) {
                //     return arr.some(function (v) {
                //         return haystack.indexOf(v) >= 0;
                //     });
                // }

                var expertChbxList = Ext.getCmp('richSnippetsLocationsListExpert').items.items;
                var richSnippestlocationsExpert = Ext.getCmp('richSnippetsLocationsExpert').getValue().split(',');

                expertChbxList.forEach(function(item){
                    if(richSnippestlocationsExpert.indexOf(item.inputValue) >= 0) {
                        item.setValue(item.inputValue);
                    } else {
                        item.setValue('');
                    }
                });

                var chbxList = Ext.getCmp('richSnippetsLocationsList').items.items;
                var richSnippestlocations = Ext.getCmp('richSnippetsLocations').getValue().split(',');

                chbxList.forEach(function(item){
                    if(richSnippestlocations.indexOf(item.inputValue) >= 0) {
                        item.setValue(item.inputValue);
                    } else {
                        item.setValue('');
                    }
                });
            }
        });
    },

    /**
     * loads saved/default trustedshops data into the plugin view
     * @param record
     */
    loadRecordIntoView: function(record) {
        var me = this,
            trustedShopId = record.get('trustedShopsId');

        me.getTsMainForm().loadRecord(record);
    },

    /**
     * Event on changing the store in the trustedshops config
     */
    onChangeShop: function() {
        this.loadRecord();
    },
    /**
     * Event fired on saving the trustedshops config
     */
    onSaveTrustedShops: function() {
        var me = this;
        me.saveConfiguration();
    },

    /**
     * Saves the trustedshops config
     * @param callback
     */
    saveConfiguration: function(callback) {
        var me = this,
            view = me.getTsMainForm(),
            form = view.getForm(),
            record = form.getRecord();

        callback = callback || Ext.emptyFn;
        if (!form.isValid()) {
            return;
        }
        form.updateRecord(record);
        view.setLoading(true);
        record.save({
            callback: function() {
                view.setLoading(false);
                me.loadRecordIntoView(record);
                Shopware.Notification.createGrowlMessage(me.snippets.onSaveTitle, me.snippets.onSaveText);
                if (Ext.isFunction(callback)) {
                    callback();
                }
            }
        });
    },

    /**
     * Opens The Trustedshops register page, according to the selected admin backend language
     */
    onOpenRegisterUrl: function() {
        var me = this;
        window.open(me.snippets.tsRegisterLink, '_blank');
    },

    onResetTsSettings: function () {

        var me = this,
            view = me.getTsMainForm(),
            form = view.getForm(),
            record = form.getRecord();

        Ext.Ajax.request({
            url: '{url controller="TrustedShopsBadge" action="resetSettings"}',
            method: 'POST',
            params: {
                shopId: record.get('shopId')
            },
            success: function (response, operation) {
                view.setLoading(true);
                me.loadRecord();
                me.loadRecordIntoView(record);
                view.setLoading(false);

                Shopware.Notification.createGrowlMessage(me.snippets.onSaveTitle, me.snippets.onSaveText);
            }
        })

    },

    /**
     *
     * @param panel
     * @param newValue
     */
    onChangeExpertModeSetting: function(panel, newValue) {
        var tabpanel = Ext.ComponentQuery.query('panel[id=tsTabs]')[0];
        var expertTab = Ext.getCmp('expertTab');
        var standardTab = Ext.getCmp('standardTab');

        if (newValue === true) {
            var standardDeliveryTime = panel.down("trustedShops-main-badge").down('fieldset[name=deliveryTimeSettingsFieldset]').down('numberfield[name=trustedShopsInStockDeliveryTime]').getValue();
            var standardNotInStockDeliveryTime = panel.down("trustedShops-main-badge").down('fieldset[name=deliveryTimeSettingsFieldset]').down('numberfield[name=trustedShopsNotInStockDeliveryTime]').getValue();
            var standardReviewsTabName = panel.down("trustedShops-main-badge").down('textfield[name=prodReviewStickerTabName]').getValue();
            panel.down("trustedShops-main-expert").down('fieldset[name=deliveryTimeSettingsFieldsetExpert]').down('numberfield[name=trustedShopsInStockDeliveryTimeExpert]').setValue(standardDeliveryTime);
            panel.down("trustedShops-main-expert").down('fieldset[name=deliveryTimeSettingsFieldsetExpert]').down('numberfield[name=trustedShopsNotInStockDeliveryTimeExpert]').setValue(standardNotInStockDeliveryTime);
            panel.down("trustedShops-main-expert").down('textfield[name=prodReviewStickerTabNameExpert]').setValue(standardReviewsTabName);

            tabpanel.setActiveTab(expertTab);
            tabpanel.child('#expertTab').tab.show();
            tabpanel.child('#standardTab').tab.hide();

        } else {
            var expertDeliveryTime = panel.down("trustedShops-main-expert").down('fieldset[name=deliveryTimeSettingsFieldsetExpert]').down('numberfield[name=trustedShopsInStockDeliveryTimeExpert]').getValue();
            var expertNotInStockDeliveryTime = panel.down("trustedShops-main-expert").down('fieldset[name=deliveryTimeSettingsFieldsetExpert]').down('numberfield[name=trustedShopsNotInStockDeliveryTimeExpert]').getValue();
            var standardReviewsTabNameExpert = panel.down("trustedShops-main-expert").down('textfield[name=prodReviewStickerTabNameExpert]').getValue();
            panel.down("trustedShops-main-badge").down('fieldset[name=deliveryTimeSettingsFieldset]').down('numberfield[name=trustedShopsInStockDeliveryTime]').setValue(expertDeliveryTime);
            panel.down("trustedShops-main-badge").down('fieldset[name=deliveryTimeSettingsFieldset]').down('numberfield[name=trustedShopsNotInStockDeliveryTime]').setValue(expertNotInStockDeliveryTime);
            panel.down("trustedShops-main-badge").down('fieldset[name=productReviewStickerFieldset]').down('textfield[name=prodReviewStickerTabName]').setValue(standardReviewsTabNameExpert);

            tabpanel.setActiveTab(standardTab);
            tabpanel.child('#expertTab').tab.hide();
            tabpanel.child('#standardTab').tab.show();
        }
    },

    onChangeStarsSwitch: function (panel, newValue) {
        if (newValue === true) {
            panel.down().down('checkbox[name=hideEmptyStarRatings]').setDisabled(false);
            panel.down().down('textfield[name=starColor]').setDisabled(false);
            panel.down().down('numberfield[name=starSize]').setDisabled(false);
            panel.down().down('numberfield[name=fontSize]').setDisabled(false);
        } else {

            panel.down().down('checkbox[name=hideEmptyStarRatings]').setDisabled(true);
            panel.down().down('textfield[name=starColor]').setDisabled(true);
            panel.down().down('numberfield[name=starSize]').setDisabled(true);
            panel.down().down('numberfield[name=fontSize]').setDisabled(true);

        }
    },
    onChangeStarsSwitchExpert: function (panel, newValue) {
        if (newValue === true) {
            panel.down().down('textarea[name=trustedShopsShowRatingsStarsCode]').setDisabled(false);
            panel.down().down('textfield[name=reviewStarsSelector]').setDisabled(false);

        } else {
            panel.down().down('textarea[name=trustedShopsShowRatingsStarsCode]').setDisabled(true);
            panel.down().down('textfield[name=reviewStarsSelector]').setDisabled(true);
        }
    },

    onChangeStickerSwitch: function (panel, newValue) {
        if (newValue === true) {
            panel.down().down('textfield[name=prodReviewStickerTabName]').setDisabled(false);
            panel.down().down('textfield[name=prodStickerBorderColor]').setDisabled(false);
            panel.down().down('textfield[name=prodStickerStarColor]').setDisabled(false);
            panel.down().down('textfield[name=reviewStickerBackgroundColor]').setDisabled(false);
            panel.down().down('numberfield[name=reviewStickerStarSize]').setDisabled(false);

        } else {
            panel.down().down('textfield[name=prodReviewStickerTabName]').setDisabled(true);
            panel.down().down('textfield[name=prodStickerBorderColor]').setDisabled(true);
            panel.down().down('textfield[name=prodStickerStarColor]').setDisabled(true);
            panel.down().down('textfield[name=reviewStickerBackgroundColor]').setDisabled(true);
            panel.down().down('numberfield[name=reviewStickerStarSize]').setDisabled(true);
        }
    },
    onChangeStickerSwitchExpert: function (panel, newValue) {
        if (newValue === true) {
            panel.down().down('textarea[name=trustedShopsShowReviewStickerCode]').setDisabled(false);
            panel.down().down('textfield[name=prodReviewStickerTabNameExpert]').setDisabled(false);

            if(panel.down().down('textfield[name=prodReviewStickerTabNameExpert]').getValue() === '') {

                panel.down().down('textfield[name=prodReviewStickerTabNameExpert]').setValue('Trusted Shops Bewertungen');
            }
            panel.down().down('textfield[name=reviewStickerSelector]').setDisabled(false);

        } else {
            panel.down().down('textarea[name=trustedShopsShowReviewStickerCode]').setDisabled(true);
            panel.down().down('textfield[name=prodReviewStickerTabNameExpert]').setDisabled(true);
            panel.down().down('textfield[name=reviewStickerSelector]').setDisabled(true);
        }
    },
    onEnableRatingsCollection: function (panel, newValue) {
        if (newValue === true) {
            if(panel.down().down('textfield[name=prodReviewStickerTabName]').getValue() === '') {

                panel.down().down('textfield[name=prodReviewStickerTabName]').setValue('Trusted Shops Bewertungen');
            }

            panel.down().down('fieldset[name=productReviewStickerFieldset]').setVisible(true);
            panel.down().down('fieldset[name=productReviewStarsFieldset]').setVisible(true);

        } else {

            panel.down().down('fieldset[name=productReviewStickerFieldset]').setVisible(false);
            panel.down().down('fieldset[name=productReviewStarsFieldset]').setVisible(false);

        }
    },
    onEnableRatingsCollectionExpert: function (panel, newValue) {
        if (newValue === true) {

            panel.down().down('fieldset[name=trustedShopsRatingStarsExpertFieldset]').setVisible(true);
            panel.down().down('fieldset[name=trustedShopsReviewStickerExpertFieldset]').setVisible(true);


        } else {

            panel.down().down('fieldset[name=trustedShopsRatingStarsExpertFieldset]').setVisible(false);
            panel.down().down('fieldset[name=trustedShopsReviewStickerExpertFieldset]').setVisible(false);
        }
    },

    onChangeDeliveryTimeOfProduct: function (panel, newValue) {
        if (newValue.deliveryTimeOfProduct === 'product') {
            panel.down().down('fieldset[name=deliveryTimeSettingsFieldset]').down('numberfield[name=trustedShopsInStockDeliveryTime]').setVisible(false);

        } else if (newValue.deliveryTimeOfProduct === 'custom') {
            panel.down().down('fieldset[name=deliveryTimeSettingsFieldset]').down('numberfield[name=trustedShopsInStockDeliveryTime]').setVisible(true);
        }
    },

    onChangeNaDeliveryTimeOfProduct: function (panel, newValue) {
        if (newValue.naDeliveryTimeOfProduct === 'product') {
            panel.down().down('fieldset[name=deliveryTimeSettingsFieldset]').down('numberfield[name=trustedShopsNotInStockDeliveryTime]').setVisible(false);

        } else if (newValue.naDeliveryTimeOfProduct === 'custom') {
            panel.down().down('fieldset[name=deliveryTimeSettingsFieldset]').down('numberfield[name=trustedShopsNotInStockDeliveryTime]').setVisible(true);
        }
    },



    onChangeDeliveryTimeOfProductExpert: function (panel, newValue) {
        if (newValue.deliveryTimeOfProductExpert === 'product') {
            panel.down().down('fieldset[name=deliveryTimeSettingsFieldsetExpert]').down('numberfield[name=trustedShopsInStockDeliveryTimeExpert]').setVisible(false);

        } else if (newValue.deliveryTimeOfProductExpert === 'custom') {
            panel.down().down('fieldset[name=deliveryTimeSettingsFieldsetExpert]').down('numberfield[name=trustedShopsInStockDeliveryTimeExpert]').setVisible(true);
        }
    },

    onChangeNaDeliveryTimeOfProductExpert: function (panel, newValue) {
        if (newValue.naDeliveryTimeOfProductExpert === 'product') {
            panel.down().down('fieldset[name=deliveryTimeSettingsFieldsetExpert]').down('numberfield[name=trustedShopsNotInStockDeliveryTimeExpert]').setVisible(false);

        } else if (newValue.naDeliveryTimeOfProductExpert === 'custom') {
            panel.down().down('fieldset[name=deliveryTimeSettingsFieldsetExpert]').down('numberfield[name=trustedShopsNotInStockDeliveryTimeExpert]').setVisible(true);
        }
    },


    onEnableCustomerRatings: function (panel, newValue) {
        if (newValue === true) {

            panel.down().down('combobox[name=customerRatingsFontFamily]').setDisabled(false);
            panel.down().down('combobox[name=customerRatingsReviews]').setDisabled(false);
            panel.down().down('combobox[name=customerRatingsBetterThan]').setDisabled(false);
            panel.down().down('textfield[name=customerRatingsBackgroundColor]').setDisabled(false);

        } else {
            panel.down().down('combobox[name=customerRatingsFontFamily]').setDisabled(true);
            panel.down().down('combobox[name=customerRatingsReviews]').setDisabled(true);
            panel.down().down('combobox[name=customerRatingsBetterThan]').setDisabled(true);
            panel.down().down('textfield[name=customerRatingsBackgroundColor]').setDisabled(true);
        }
    },

    onChangeCustomerRatingsActiveExpert: function (panel, newValue) {
        if (newValue === true) {
            panel.down().down('textarea[name=customerRatingsExpertCode]').setDisabled(false);
            panel.down().down('textfield[name=customerReviewsSelector]').setDisabled(false);

        } else {
            panel.down().down('textarea[name=customerRatingsExpertCode]').setDisabled(true);
            panel.down().down('textfield[name=customerReviewsSelector]').setDisabled(true);
        }
    },

    onEnableRichSnippets: function (panel, newValue) {
        if (newValue === true) {
            panel.down().down('checkboxgroup[name=richSnippetsLocationsList]').setDisabled(false);
        }
        else {
            panel.down().down('checkboxgroup[name=richSnippetsLocationsList]').setDisabled(true);
        }
    },

    onEnableRichSnippetsExpert: function (panel, newValue) {
        if (newValue === true) {
            panel.down().down('checkboxgroup[name=richSnippetsLocationsListExpert]').setDisabled(false);
            panel.down().down('textarea[name=richSnippetsExpertCode]').setDisabled(false);
        }
        else {
            panel.down().down('checkboxgroup[name=richSnippetsLocationsListExpert]').setDisabled(true);
            panel.down().down('textarea[name=richSnippetsExpertCode]').setDisabled(true);
        }
    }
});
//{/block}