
//{namespace name="trusted_shops_badge"}

//{block name="backend/trusted_shops_badge/view/window"}
Ext.define('Shopware.apps.TrustedShopsBadge.view.main.Window', {
    extend: 'Enlight.app.Window',
    alias: 'widget.trustedShops-main-window',
    overflowY: 'scroll',
    layout: 'anchor',

    /**
     * Contains snippets for the Tab Panel
     * @object
     */
    snippets: {
        title:          '{s name=window/title}{/s}',
        chooseShop:     '{s name=window/chooseShop}{/s}',
        trustedShopsId: '{s name=window/trustedShopsId}{/s}',
        saveButton:     '{s name=save_button}{/s}',
        modeLabel: '{s name=window/modeLabel}{/s}',
        tsidHelpText: '{s name=window/tsidHelpText}{/s}',
        trustedShopsRegisterUrl: '{s name=window/trustedShopsRegisterUrl}{/s}',
        expertComboOption: '{s name=window/expertComboOption}{/s}',
        standardComboOption: '{s name=window/standardComboOption}{/s}',
        resetButton: '{s name=window/resetButton}{/s}',

        tab: {
            expert: '{s name=window/tab/tsExpertModeTab}{/s}',
            badge: '{s name=window/tab/tsStandardModeTab}{/s}'
        }
    },

    /**
     * Initializing the panel
     * @return void
     */
    initComponent: function() {
        var me = this;
        // var tabpanelselector = Ext.ComponentQuery.query('container[id=tsBadgePanel]');
        me.title = me.snippets.title;

        var expertModeSwitch = Ext.create('Ext.data.Store', {
            fields: [
                'val',
                'text'
            ],
            data: [
                { 'val': false, 'text': me.snippets.standardComboOption },
                { 'val': true, 'text': me.snippets.expertComboOption }
            ]
        });



        var infoPanel = Ext.create('Ext.panel.Panel', {
            plain: false,
            itemId: 'tsInfo',
            layout: 'anchor',
            items: [
                {
                    xtype:'fieldset',
                    columnWidth: '100%',
                    title: 'Information',
                    collapsible: false,
                    defaultType: 'textfield',
                    defaults: {
                        anchor: '100%',
                        labelWidth: 250
                    },
                    style: {
                        background: '#EAEAEA'
                    },
                    items : [
                        {
                            xtype: 'panel',
                            border: false,
                            height: 400,
                            html: '{s name=window/tsConfigImage}<br/><center><img src=\\"{link file=\\"backend/trusted_shops_badge/images/trustedshops_en.png\\"}\\"></center><br/>{/s}'
                        },
                        {
                            xtype: 'button',
                            name: 'trustedShopsRegisterUrl',
                            text: me.snippets.trustedShopsRegisterUrl,
                            cls: 'primary',
                            handler: function () {
                                me.fireEvent('openRegisterUrl')
                            },
                            style: {
                                marginTop: '10px',
                                marginBottom: '10px'
                            }
                        },
                        {
                            xtype: 'button',
                            name: 'resetSettings',
                            iconCls: 'sprite-bin-metal-full',
                            text: me.snippets.resetButton,
                            handler: function () {
                                me.fireEvent('resetTsSettings')
                            },
                            style: {
                                marginBottom: '30px'
                            }
                        },
                        {
                            xtype: 'textfield',
                            name: 'trustedShopsId',
                            itemId: 'trustedShopsId',
                            id: 'trustedShopsId',
                            fieldLabel: me.snippets.trustedShopsId,
                            helpText: me.snippets.tsidHelpText,
                            style: {
                                marginBottom: '10px'
                            }
                        },
                        {
                            xtype: 'combobox',
                            name: 'expertMode',
                            store: expertModeSwitch,
                            displayField: 'text',
                            valueField: 'val',
                            value: false,
                            queryMode: 'local',
                            fieldLabel: me.snippets.modeLabel,
                            forceSelection: true,
                            editable: false,
                            listeners: {
                                change: function(comboBox, newValue){
                                    me.fireEvent('onChangeExpertModeSetting', me, newValue);
                                }
                            }
                        }
                    ]
                }
            ]
        });

        var tabPanel = Ext.create('Ext.tab.Panel', {
            plain: false,
            itemId: 'tsTabs',
            id: 'tsTabs',
            items: [
                {
                    title: me.snippets.tab.badge,
                    id: 'standardTab',
                    itemId: 'standardTab',
                    xtype: 'trustedShops-main-badge',
                    hidden: false,
                    style: {
                        background: "#F0F0F0"
                    }
                },
                {
                    title: me.snippets.tab.expert,
                    xtype: 'trustedShops-main-expert',
                    itemId: 'expertTab',
                    id: 'expertTab',
                    hidden: true,
                    style: {
                        background: "#F0F0F0"
                    }
                },
                {
                    tabConfig: {
                        xtype: 'tbfill'
                    }
                }
            ]
        });

        me.formPanel = Ext.create('Ext.form.Panel', {
            name: 'trusted-shops-form-panel',
            items: [infoPanel, tabPanel],
            border: false
        });

        me.dockedItems = [me.getTopToolbar()];
        me.dockedItems.push(me.getBottomToolbar());
        me.items = [me.formPanel];

        me.callParent(arguments);
    },

    /**
     * Defining events fired by "witching the shop" and "saving the trusted shops config"
     *
     * @return void
     */
    registerEvents: function() {
        var me = this;

        me.addEvents(

            /**
             * @event changeShop
             * @param [int] shopId
             */
            'changeShop',

            /**
             * @event saveTrustedShops
             * @param [Ext.form.Panel] view
             */
            'saveTrustedShops',

            /**
             * @event changeExpertModeSetting
             */
            'onChangeExpertModeSetting',

            'openRegisterUrl',

            'resetTsSettings'

        );
    },

    /**
     * Creating the grid toolbar with the shop picker combobox
     * @return [Ext.toolbar.Toolbar] grid toolbar
     */
    getTopToolbar: function() {
        var me = this;
        var shopStore = Ext.create('Shopware.apps.Base.store.Shop');
        shopStore.filters.clear();
        shopStore.load({
            callback: function(records) {
                shopCombo.setValue(records[0].get('id'));
            }
        });

        var shopCombo = Ext.create('Ext.form.field.ComboBox',
            {
                fieldLabel: me.snippets.chooseShop,
                store: shopStore,
                labelWidth: 80,
                name: 'shop-combo',
                margin: '3px 6px 3px 0',
                queryMode: 'local',
                valueField: 'id',
                editable: false,
                displayField: 'name',
                listeners: {
                    'select': function() {
                        if (this.store.getAt('0')) {
                            me.fireEvent('changeShop');
                        }
                    }
                }
            });

        var toolbar = Ext.create('Ext.toolbar.Toolbar', {
            dock: 'top',
            ui: 'shopware-ui',
            items: [
                '->',
                shopCombo
            ]
        });

        return toolbar;
    },

    /**
     * Creating the bottom toolbar wwith the "save" button
     * @return array
     */
    getBottomToolbar: function() {
        var me = this;
        return Ext.create('Ext.toolbar.Toolbar', {
            ui: 'shopware-ui',
            dock: 'bottom',
            cls: 'shopware-toolbar',
            items: [
                '->',
                /*{if {acl_is_allowed privilege=update}}*/
                {
                    text: me.snippets.saveButton,
                    action: 'save',
                    cls: 'primary',
                    formBind: true,
                    handler: function() {
                        me.fireEvent('saveTrustedShops');
                    }
                }
                /*{/if}*/
            ]
        });
    }
});
//{/block}